pub struct SearchCommands {
pub search_query: Option<Vec<SearchQuery>>,
pub image_query: Option<Vec<SearchQuery>>,
pub open: Option<Vec<OpenOperation>>,
pub click: Option<Vec<ClickOperation>>,
pub find: Option<Vec<FindOperation>>,
pub screenshot: Option<Vec<ScreenshotOperation>>,
pub finance: Option<Vec<FinanceOperation>>,
pub weather: Option<Vec<WeatherOperation>>,
pub sports: Option<Vec<SportsOperation>>,
pub time: Option<Vec<TimeOperation>>,
pub response_length: Option<SearchResponseLength>,
}Fields
search_query: Option<Vec<SearchQuery>>Query the internet search engine for a given list of queries.
image_query: Option<Vec<SearchQuery>>Query the image search engine for a given list of queries.
open: Option<Vec<OpenOperation>>Open pages by reference id or URL.
click: Option<Vec<ClickOperation>>Open links from previously opened pages.
find: Option<Vec<FindOperation>>Find text patterns in pages.
screenshot: Option<Vec<ScreenshotOperation>>Take screenshots of PDF pages.
finance: Option<Vec<FinanceOperation>>Look up prices for the given stock symbols.
weather: Option<Vec<WeatherOperation>>Look up weather forecasts.
sports: Option<Vec<SportsOperation>>Look up sports schedules and standings.
time: Option<Vec<TimeOperation>>Get time for the given UTC offsets.
response_length: Option<SearchResponseLength>Set the length of the response to be returned.