pub struct SearchQuery {
pub q: String,
pub recency: Option<u64>,
pub domains: Option<Vec<String>>,
}Fields
q: StringSearch query.
recency: Option<u64>Whether to filter by recency, as a number of recent days.
domains: Option<Vec<String>>Whether to filter by a specific list of domains.